@@ -26,12 +26,18 @@ import time
 import gc
 import subprocess
 import requests
+import board
+import digitalio
 import displayio
 import wget as wget_lib
 from adafruit_bitmap_font import bitmap_font
 from adafruit_display_text.label import Label
 from adafruit_io.adafruit_io import IO_HTTP, AdafruitIO_RequestError
+from adafruit_stmpe610 import Adafruit_STMPE610_SPI
 from PIL import Image
+import neopixel
+import adafruit_focaltouch
+import adafruit_ili9341
 
 try:
     from secrets import secrets  # pylint: disable=no-name-in-module
@@ -85,6 +91,8 @@ class PyPortal:
                         use regexp.
     :param default_bg: The path to your default background image file or a hex color.
                        Defaults to 0x000000.
+    :param status_neopixel: The pin for the status NeoPixel. Use ``board.NEOPIXEL`` for the on-board
+                            NeoPixel. Defaults to ``None``, no status LED
     :param str text_font: The path to your font file for your data text display.
     :param text_position: The position of your extracted text on the display in an (x, y) tuple.
                           Can be a list of tuples for when there's a list of json_paths, for example
@@ -114,6 +122,7 @@ class PyPortal:
     :param caption_color: The color of your caption. Must be a hex value, e.g. ``0x808000``.
     :param image_url_path: The HTTP traversal path for a background image to display.
                            Defaults to ``None``.
+    :param busio.SPI external_spi: A previously declared spi object. Defaults to ``None``.
     :param debug: Turn on debug print outs. Defaults to False.
     :param display: The displayio display object to use
     :param touchscreen: The touchscreen object to use. Usually STMPE610 or FocalTouch.
@@ -129,6 +138,7 @@ class PyPortal:
         json_path=None,
         regexp_path=None,
         default_bg=0x000000,
+        status_neopixel=None,
         text_font=None,
         text_position=None,
         text_color=0x808080,
@@ -146,6 +156,7 @@ class PyPortal:
         caption_color=0x808080,
         image_url_path=None,
         success_callback=None,
+        external_spi=None,
         debug=False,
         display=None,
         touchscreen=None
@@ -153,11 +164,23 @@ class PyPortal:
 
         self._debug = debug
         self._debug_start = time.monotonic()
-
-        if display is None:
-            raise RuntimeError("Display must be provided")
         self.display = display
 
+        if external_spi:  # If SPI Object Passed
+            spi = external_spi
+        else:  # Else: Make ESP32 connection
+            spi = board.SPI()
+
+        if self.display is None:
+            display_bus = displayio.FourWire(
+                spi, command=board.D25, chip_select=board.CE0
+            )
+            self.display = adafruit_ili9341.ILI9341(display_bus, width=320, height=240)
+
+        if self.display is None:
+            raise RuntimeError("Display not found or provided")
+        # self.set_backlight(1.0)  # turn on backlight
+
         self._url = url
         self._headers = headers
         if json_path:
@@ -171,8 +194,13 @@ class PyPortal:
         self._regexp_path = regexp_path
         self._success_callback = success_callback
 
-        self.neopix = None
-        self._audio_device = 1
+        if status_neopixel:
+            self.neopix = neopixel.NeoPixel(status_neopixel, 1, brightness=0.2)
+        else:
+            self.neopix = None
+        self.neo_status(0)
+
+        self.audio_device = 1
 
         try:
             os.stat(LOCALFILE)
@@ -283,14 +311,29 @@ class PyPortal:
                     self.display.height,
                 )  # default to full screen
 
-        if touchscreen is not None:
-            self._debug_print("Init touchscreen")
-            self.touchscreen = touchscreen
-
-            self.set_backlight(1.0)  # turn on backlight
-        else:
+        self._debug_print("Init touchscreen")
+        self.touchscreen = touchscreen
+        # Attempt to Init STMPE610
+        if self.touchscreen is None:
+            self._debug_print("Attempting to initialize STMPE610...")
+            try:
+                chip_select = digitalio.DigitalInOut(board.CE1)
+                self.touchscreen = Adafruit_STMPE610_SPI(spi, chip_select)
+            except RuntimeError:
+                self._debug_print("None Found")
+        # Attempt to Init FocalTouch
+        if self.touchscreen is None:
+            self._debug_print("Attempting to initialize Focal Touch...")
+            try:
+                i2c = board.I2C()
+                self.touchscreen = adafruit_focaltouch.Adafruit_FocalTouch(i2c)
+            except (OSError, ValueError):
+                self._debug_print("None Found")
+        if self.touchscreen is None:
             raise AttributeError("PyPortal module requires a touchscreen.")
 
+        self.set_backlight(1.0)  # turn on backlight
+
         gc.collect()
 
     def set_headers(self, headers):
@@ -444,7 +487,7 @@ class PyPortal:
         :param str file_name: The name of the wav file to play on the speaker.
         """
         self._debug_print("Playing audio file", file_name)
-        os.system("aplay -Dhw:" + str(self._audio_device) + ",0 " + file_name)
+        os.system("aplay -Dhw:" + str(self.audio_device) + ",0 " + file_name)
         if not wait_to_finish:
             # To do: Add threading support
             print("Immediately returning not currently supported.")
@@ -518,7 +561,9 @@ class PyPortal:
         :param filename: The name of the file to save the data to.
         """
         print("Fetching stream from", url)
+        self.neo_status((100, 100, 0))
         wget_lib.download(url, filename)
+        self.neo_status((0, 0, 0))
 
     # pylint: enable=no-self-use
 
@@ -646,9 +691,11 @@ class PyPortal:
         if not r:
             # great, lets get the data
             print("Retrieving data...", end="")
+            self.neo_status((100, 100, 0))  # yellow = fetching data
             gc.collect()
             r = requests.get(self._url, headers=self._headers, timeout=timeout)
             gc.collect()
+            self.neo_status((0, 0, 100))  # green = got data
             print("Reply is OK!")
 
         self._debug_print(r.text)
